library(ggplot2)
library(foreach)

drawFig_3c=function(df, addPeaks, col2show, file, remap, nArray, array_replicate_colors,rnaseq_replicate_colors){
  
  p <- ggplot(df, aes(X1, X2)) + geom_point(alpha=0, size=2, colour=col2show) + stat_density2d()
  p <- p + geom_point(data=remap[1:nArray,], aes(X1, X2), fill = array_replicate_colors, size=4, shape=23)
  p <- p + geom_point(data=remap[(nArray+1):nrow(remap),], aes(X1, X2), fill = rnaseq_replicate_colors, size=4, shape=25)
  
  
  
  if(addPeaks){
    p <- p + geom_point(data=peaks, aes(X1, X2), colour = "red", size=6.5, fill=NA, shape=1)
    p <- p + geom_point(data=peaks, aes(X1, X2), colour = "red", size=6, fill=NA, shape=1)
    for (j in 1:dim(peaks)[1]){
      p <- p + annotate("text", label = as.character(j), x = peaks[j,1], y = peaks[j,2], size=4)
    }
  }
  p = p + theme(axis.line=element_blank(),
                axis.text.x=element_blank(),
                axis.text.y=element_blank(),
                axis.text.x = element_blank(),
                axis.title.x=element_blank(),
                axis.title.y=element_blank())
  ggsave(filename = paste(file,".pdf",sep=""))
  graphics.off()
  
}

setwd("D:\\Research\\UTA\\Dropbox (Compbio)\\Projects\\Leukemia\\Submission\\Remapping\\Remapping_results")

d=read.table("AML_gsm_annot.txt", sep="\t", header=T, stringsAsFactors=F)
colnames(d)=c("gsm",  "series_id","Sample.type","Main.category","Category.specifying.lineage.tumor.origin",
              "Category.specifying.subtype","Further.specifications.on.category","GENETICS1","GENETICS2","Tumor.type",
              "CLINICAL","Sub.maps.available","Patient.identifier","Source","Isolation",
              "Purity.Tumor.cell.content","Gender","Race","Age","Marker.phenotype",
              "Survival.status..0.alive.1.dead.","Survival.time","EF.PF.status","EF.survival","G_S_P",
              "In.vivo.treatment","In.vivo.treatment.time","Cultured","Ex.vivo.treatment","Ex.vivo.treatment.time",
              "NOTES","altGSMs", "altGSEs", "CLASS","MAINCLASS")



coord=read.table("AML_15pct_BHSNE_mean-shift.txt", sep="\t", header=T, stringsAsFactors=F)
peaks=read.table("AML_15pct_BHSNE_mean-shift_cluster_centroids_1.5.txt", sep="\t", header=T, stringsAsFactors=F)

all(d[,1]==coord[,1])
dd=cbind(d,coord)


#Reading in coordinate tables
remapped_array=read.table("remapped_aml_coordinates.txt", sep="\t", header=T, stringsAsFactors=F)
remapped_seq=read.table("annotated_coordinates.txt", sep="\t", header=T, stringsAsFactors=F)

#Find indices of counterparts for coloring
rownames(dd) = dd$gsm
remapped_array_counterparts = remapped_array[,1]
array_counterpart_ind = match(remapped_array_counterparts, dd[,1])
counterparts = dd[c(remapped_array_counterparts),38:39]


remapped=rbind(remapped_array[,2:3], remapped_seq[,2:3])
nArray = nrow(remapped_array)
colnames(remapped)=c("X1","X2")
remapped[,1]=as.numeric(sub(",", ".", remapped[,1]))
remapped[,2]=as.numeric(sub(",", ".", remapped[,2]))

#Handling the coloring
dat2show=cbind(dd$x,dd$y)
df=as.data.frame(dat2show)
colnames(df) = c("X1","X2")
col2show=rep("grey", dim(dat2show)[1])
sig_tol_range=1.5
addPeaks=T
front=1:nrow(dat2show)%in%1:3

# Coloring of microarray replicates ----
normk=1:nrow(dd)%in%c(grep("normal karyotype", dd$GENETICS1),grep("Normal", dd$GENETICS1),grep("CN", dd$GENETICS1),grep("NN",dd$GENETICS1))&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS))
## 867
t8_21=1:nrow(dd)%in%grep("8;21", dd$GENETICS1)&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##101
MLL_aml=1:nrow(dd)%in%grep("MLL", dd$GENETICS1)&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##108
complex=1:nrow(dd)%in%grep("complex karyotype", dd$GENETICS1)&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##42
t15_17=1:nrow(dd)%in%grep("15;17", dd$GENETICS1)&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##93
ab5_7=1:nrow(dd)%in%c(grep("-5/7", dd$GENETICS1),grep("-7", dd$GENETICS1))&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##16
ab16=1:nrow(dd)%in%c(grep("idt\\(16\\)", dd$GENETICS1),grep("inv\\(16\\)", dd$GENETICS1),grep("inv16", dd$GENETICS1))&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##89 NO deletions included
add8=1:nrow(dd)%in%c(grep("\\+8",dd$GENETICS1),grep("trisomy 8", dd$GENETICS1))&(1:nrow(dd)%in%grep("Leukemia_AML",dd$CLASS)) ##19

knownGenet=normk|t8_21|t15_17|MLL_aml|ab5_7|ab16|add8|complex

classifiable=t8_21|t15_17|MLL_aml|ab16


col2show=rep("dimgrey", dim(dat2show)[1])
col2show[normk]="#9fb4e2ff" #Normal karyotype cornflowerblue
col2show[t8_21]="#7cd4dbff" #AML1-ETO cyan 
col2show[t15_17]="#9f61b7ff" #PML-PARA purple
col2show[ab5_7]="turquoise4" 
col2show[ab16]="#c048abff" #CBFB-MYH11 magenta
col2show[add8]="red"
col2show[MLL_aml]="#f7c8d8ff" #MLL pink
col2show[complex]="tan2"

col2show[ab5_7|add8|complex] = "#e8b075ff" #OTHER
front=normk|t8_21|t15_17|MLL_aml|ab5_7|ab16|add8
array_replicate_colors = col2show[array_counterpart_ind]

# Coloring of rna seq samples ----
dd_rna = read.table("annotated_coordinates.txt", sep="\t", header=T, stringsAsFactors=F)
normk=1:nrow(dd_rna)%in%c(grep("Normal", dd_rna$coloring))
t8_21=1:nrow(dd_rna)%in%c(grep("RUNX1-RUNX1T1", dd_rna$coloring)) 
MLL_aml=1:nrow(dd_rna)%in%grep("MLL", dd_rna$coloring)
complex=1:nrow(dd_rna)%in%grep("Complex Karyotype", dd_rna$coloring)
t15_17=1:nrow(dd_rna)%in%grep("PML-RARA", dd_rna$coloring) 
ab5_7=1:nrow(dd_rna)%in%c(grep("ab5_7", dd_rna$coloring)) 
ab16=1:nrow(dd_rna)%in%c(grep("CBFB-MYH11", dd_rna$coloring))
add8=1:nrow(dd_rna)%in%c(grep("add8", dd_rna$coloring))
other=1:nrow(dd_rna)%in%c(grep("other", dd_rna$coloring))

col2show_rna=rep("dimgrey", dim(dd_rna)[1])
col2show_rna[normk]="#9fb4e2ff" #Normal karyotype cornflowerblue
col2show_rna[t8_21]="#7cd4dbff" #AML1-ETO cyan 
col2show_rna[t15_17]="#9f61b7ff" #PML-PARA purple
col2show_rna[ab5_7]="turquoise4" 
col2show_rna[ab16]="#c048abff" #CBFB-MYH11 magenta
col2show_rna[add8]="red"
col2show_rna[MLL_aml]="#f7c8d8ff" #MLL pink
col2show_rna[complex]="tan2"

col2show_rna[ab5_7|add8|complex|other] = "#e8b075ff" #OTHER
front_rna=normk|t8_21|t15_17|MLL_aml|ab5_7|ab16|add8


rnaseq_replicate_colors = col2show_rna

drawFig_3c(df, T, col2show, paste("AML_15pct_genes_remapped_all_rna_3c", sep=""),remapped, 
        nArray, array_replicate_colors, rnaseq_replicate_colors)

