#Runs mean shift clustering and compares the result with the original
library(LPCM)
library(foreach)
library(flexclust)
setwd("/Users/Hayrynen/Dropbox (Compbio)/Projects/Leukemia/Data/AML_map") # On Mac

# Validating on AML maps first.
####### Loading in AML annotations, mapping results and original cluster centroids ----
#Coordinates
coord=read.table("AML_15pct_BHSNE_mean-shift.txt", sep="\t", header=T, stringsAsFactors=F)
peaks=read.table("AML_15pct_BHSNE_mean-shift_cluster_centroids_1.5.txt", sep="\t", header=T, stringsAsFactors=F)
#Annotations

d=read.table("AML_gsm_annot.txt", sep="\t", header=T, stringsAsFactors=F)
colnames(d)=c("gsm",  "series_id","Sample.type","Main.category","Category.specifying.lineage.tumor.origin",
              "Category.specifying.subtype","Further.specifications.on.category","GENETICS1","GENETICS2","Tumor.type",
              "CLINICAL","Sub.maps.available","Patient.identifier","Source","Isolation",
              "Purity.Tumor.cell.content","Gender","Race","Age","Marker.phenotype",
              "Survival.status..0.alive.1.dead.","Survival.time","EF.PF.status","EF.survival","G_S_P",
              "In.vivo.treatment","In.vivo.treatment.time","Cultured","Ex.vivo.treatment","Ex.vivo.treatment.time",
              "NOTES","altGSMs", "altGSEs", "CLASS","MAINCLASS")
all(d[,1]==coord[,1])
dd=cbind(d,coord)
only_coord = coord[,2:3]
#######
#######
####### Reading in replicate data ----

setwd("/Users/Hayrynen/Dropbox (Compbio)/Projects/Leukemia/Remapping/Remapping_results")
remapped_array=read.table("remapped_aml_coordinates.txt", sep="\t", header=T, stringsAsFactors=F) #Microarray samples
remapped_seq=read.table("remapped_tcga_coordinates.txt", sep="\t", header=T, stringsAsFactors=F) #RNA-seq samples
#Find indices of counterparts for coloring
rownames(dd) = dd$gsm
remapped_array_counterparts = remapped_array[,1]
array_counterpart_ind = match(remapped_array_counterparts, dd[,1])

remapped_rnaseq_counterparts = remapped_seq[,1]
rnaseq_counterpart_ind = match(remapped_rnaseq_counterparts,dd[,1])
counterparts = dd[c(remapped_array_counterparts, remapped_rnaseq_counterparts),38:39]
#Finishing data frame of remapped samples
remapped=rbind(remapped_array[,2:3], remapped_seq[,3:4])
nArray = nrow(remapped_array)
colnames(remapped)=c("X1","X2")
remapped[,1]=as.numeric(sub(",", ".", remapped[,1]))
remapped[,2]=as.numeric(sub(",", ".", remapped[,2]))

###### Clustering ----

#### Checking clusters of RNA-Seq samples ----

#### All rnaseq samples 
tcga_labels = rep(NA,162)
remapped_seq_all=read.table("remapped_tcga_rnaseq_all.txt", sep="\t", header=T, stringsAsFactors=F)#RNA-seq samples
colnames(remapped_seq_all) = c("tcga_GSM", "X1", "X2")
colnames(only_coord) = c("X1", "X2")
for(i in 1:nrow(remapped_seq_all)) {
  print(i)
  temp = ms(rbind(only_coord, remapped_seq_all[i,2:3]), h=1.5, scaled=F, thr=0.01, iter=500)
  tcga_labels[i] = temp$cluster.label[1714]
}
write.table(tcga_labels, "tcga_labels.txt")



#Validating results on full map -----

#Reading in map data ----
#On Mac
setwd("/Users/Hayrynen/Dropbox (Compbio)/Projects/Leukemia/Data/Fullmap/")

coord =  read.table("data9544_15pct_BHSNE_mean-shift.txt", sep="\t", header=T, stringsAsFactors=F)
peaks = read.table("data9544_15pct_BHSNE_mean-shift_cluster_centroids_2.5.txt", sep="\t", header=T, stringsAsFactors=F)
d = read.table("USE_final_anno_columnIDsorted_data9544_withColorClass.txt", sep="\t", header=T, stringsAsFactors=F)
colnames(d)=c("gsm",  "series_id","Sample.type","Main.category","Category.specifying.lineage.tumor.origin",
              "Category.specifying.subtype","Further.specifications.on.category","GENETICS1","GENETICS2","Tumor.type",
              "CLINICAL","Sub.maps.available","Patient.identifier","Source","Isolation",
              "Purity.Tumor.cell.content","Gender","Race","Age","Marker.phenotype",
              "Survival.status..0.alive.1.dead.","Survival.time","EF.PF.status","EF.survival","G_S_P",
              "In.vivo.treatment","In.vivo.treatment.time","Cultured","Ex.vivo.treatment","Ex.vivo.treatment.time",
              "NOTES","altGSMs", "altGSEs", "CLASS","MAINCLASS")
only_coord = coord[,2:3]
all(d[,1]==coord[,1])
dd=cbind(d,coord)

#Reading in replicate data ----
setwd("/Users/Hayrynen/Dropbox (Compbio)/Projects/Leukemia/Remapping/Remapping_results/")


remapped_array = read.table('remapped_fullmap_coordinates.txt',  sep="\t", header=T, stringsAsFactors=F)

rownames(dd) = dd$gsm
remapped_array_counterparts = remapped_array[,1]
array_counterpart_ind = match(remapped_array_counterparts, dd[,1])
remapped_rnaseq_counterparts = remapped_seq[,1]
rnaseq_counterpart_ind = match(remapped_rnaseq_counterparts,dd[,1])
counterparts = dd[c(remapped_array_counterparts),38:39]


# Checking if samples go to same clusters ----
ms_w_MA_rep_2.5 = ms(rbind(only_coord, remapped_array[,2:3]), h=2.5, scaled=F, thr=0.01, iter=500)
sum(ms_w_MA_rep_2.5$cluster.label[9545:(nrow(dd)+98)] ==  ms_w_MA_rep_2.5$cluster.label[array_counterpart_ind])
