%% Setting paths
addpath('~/Matlab-scripts')
addpath('~/Leukemia/barnes-hut-sne-modified')
cd /home/hayrynes/Leukemia/Revised_remapping

%% Read in replicates
cd /home/hayrynes/Leukemia/Revised_remapping
replicate_GSMs = read_mixed_csv('Replicate_data/remappedGSMs', ',');
replicate_probeIDs = read_mixed_csv('Replicate_data/probeIDs', ',');
GSM_counterparts = ...
    read_mixed_csv('Replicate_data/GSM_of_replicates_of_remapped.txt', ',');
nReplicates = length(replicate_GSMs);
fid = fopen('Replicate_data/remappedExpr');
replicate_Expr = fscanf(fid, ...
    [repmat('%f\t',1, nReplicates - 1), '%f\n'] , [nReplicates, Inf]);
fclose(fid);


save('replicate_data.mat', 'replicate_GSMs', 'replicate_probeIDs', ...
    'replicate_Expr', 'GSM_counterparts');

%% Read in original data matrix
cd /home/hayrynes/Leukemia/Revised_remapping
data_GSMs = read_mixed_csv('Data_matrix/GSMs_testi', ',');
data_probeIDs = read_mixed_csv('Data_matrix/probeIDs', ',');
nData = length(data_GSMs);
fid = fopen('Data_matrix/Expr.txt');
data_Expr = fscanf(fid, [repmat('%f\t',1, nData - 1), '%f\n'] , ...
    [nData, Inf]);
fclose(fid);

save('data_matrix.mat', 'data_GSMs', 'data_probeIDs', 'data_Expr');

%% Read in rnaseq data
cd /home/hayrynes/Leukemia/Revised_remapping
load Data_matrix/TCGA_data
load Data_matrix/tcga_patient_ids
load Data_matrix/tcga_patient_ids_in_data

rnaseqExpressions = rnaseqExpressions_raw + 1/2;

[~,tcga_in_datamatrix, tcga_in_rna] = intersect(data_GSMs, tcga_GSMs, ...
    'stable');
tcga_microarray = data_Expr(tcga_in_datamatrix,:);
tcga_rna_all = log2(rnaseqExpressions);
tcga_rna = log2(rnaseqExpressions(rnaIND(tcga_in_rna),:));
tcgaGSMs = tcga_GSMs(rnaIND(tcga_in_rna)); 

%% Choose the genes, 15% most variable
hugo_to_entrez = read_mixed_csv('Data_matrix/uniq_homosapiens_entrez2symbol.txt', '\t');
hugo_to_entrez = cellfun(@num2str, hugo_to_entrez, 'UniformOutput', false);
for i = 1:length(data_probeIDs)
    data_entrez{i,1} = data_probeIDs{i}(1:end-3);
end

top_15p_genes = read_mixed_csv('Data_matrix/data9544_15pct_topVariating_genelist.txt', '\t');
[~ , hugo_ind, ~] = intersect(hugo_to_entrez(:,2), top_15p_genes, 'stable');
hugo_entrez = hugo_to_entrez(hugo_ind,1);
hugo_symbol = hugo_to_entrez(hugo_ind,2);

[~, data_ind, hugo_data_ind] = intersect(data_entrez, hugo_entrez, 'stable');

if length(data_ind) ~= length(top_15p_genes)
    display('SOME GENES NOT FOUND')
end


data_Expr_top15 = data_Expr(:,data_ind);
probeIDs_top15 = data_probeIDs(data_ind);
replicate_Expr_top15 = replicate_Expr(:,data_ind);


%% Read in landmark mapping coordinates (top 15 % variable genes)
cd /home/hayrynes/Leukemia/Revised_remapping
locked_fullmap = read_mixed_csv('Fullmap/data9544_15pct_BHSNE_mean-shift.txt','\t');
locked_fullmap(1,:) = [];
data_GSMs_ = locked_fullmap(:,1);
lockedMappings_fullmap = cellfun(@str2num, locked_fullmap(:,2:3));

%% Consistency checks
% Probe id consistency
[probe_intersection, ia, ib] = intersect(replicate_probeIDs, data_probeIDs);
if ~isequal(probe_intersection, replicate_probeIDs, data_probeIDs) || ...
        ~isequal(ia,ib)
    display('Inconsistency in probe annotation')
end

% Sample counterparts
GSM_intersection = intersect(data_GSMs, GSM_counterparts);
if length(GSM_intersection) ~= length(unique(GSM_counterparts))
    display('Counterparts of replicates missing from data matrix')
end

% Data GSMs

if ~isequal(data_GSMs_, data_GSMs)
    display('GSMs of locked mappings and data matrix do not agree')
end

%% Mapping parameters
initial_dims = 50;
theta = 0.3;
perplexity = 30;

%% AML map reading in and preparing data
%Base set AML
AML_base_coord_raw = ...
	read_mixed_csv('Data_matrix/AML_15pct_BHSNE_mean-shift.txt','\t');
header = AML_base_coord_raw(1,:);
AML_base_coord_raw(1,:) = [];
AML_base_GSMs = AML_base_coord_raw(:,1);
AML_base_coord = cellfun(@str2num,AML_base_coord_raw(:,2:3));

[AML_base_GSMs_, ~, AML_in_data_ind] = intersect(AML_base_GSMs, data_GSMs, 'stable');

%Checking consistency

if ~isequal(sort(AML_base_GSMs), sort(AML_base_GSMs_))
	display('Inconsistency in base map GSMs')
end

AML_base_data = data_Expr_top15(AML_in_data_ind,:);
AML_lockedMappings = AML_base_coord;
nBase = size(AML_base_data,1);


%% AML rnaseq Mapping using correlation distance and top 15% variable genes.

cd /home/hayrynes/Leukemia/barnes-hut-sne-modified
X = AML_base_data;
mappings_tcga_all_corr = fast_tsne_remapping_corr(X, ...
    initial_dims, perplexity, theta,...
    AML_lockedMappings, tcga_rna_all(:,data_ind));

save('mappings_tcga_all_corr.mat', 'AML_lockedMappings', ...
    'mappings_tcga_all_corr', 'AML_base_GSMs', 'AML_base_coord', ...
    'tcga_GSMs');


%% AML replicate remapping ( top 15% variable genes)
cd /home/hayrynes/Leukemia/barnes-hut-sne-modified
[~, AML_replicate_ind, repind] = intersect(AML_base_GSMs, GSM_counterparts, 'stable');
replicates_AML_GSMs = GSM_counterparts(repind);
replicates_AML_data = replicate_Expr_top15(repind,:);
cd /home/hayrynes/Leukemia/barnes-hut-sne-modified
X = AML_base_data;
mappings_AML_replicates = fast_tsne_remapping_eucl(X, ...
    initial_dims, perplexity, theta, AML_lockedMappings, replicates_AML_data);



%% Mapping replicates on full map (top 15% genes)
cd /home/hayrynes/Leukemia/barnes-hut-sne-modified
X = data_Expr_top15;
replicate_Expr_top15 = replicate_Expr(:,data_ind);
mappings_replicates_fullmap_top15 = fast_tsne_remapping_eucl(X, ...
    initial_dims, perplexity, theta,...
    lockedMappings_fullmap, replicate_Expr_top15);

save('mappings_replicates_fullmap_top15.mat', 'lockedMappings_fullmap', ...
    'mappings_replicates_fullmap_top15', 'replicate_GSMs', ...
    'GSM_counterparts', 'data_GSMs');

